package com.dsk.system.mapper;

import com.dsk.common.core.domain.entity.BusinessFollowRecord;
import com.dsk.system.domain.BusinessIdDto;

import java.util.List;

/**
 * 项目跟进记录Mapper接口
 * 
 * @author lxl
 * @date 2023-05-17
 */
public interface BusinessFollowRecordMapper 
{
    /**
     * 查询项目跟进记录
     * 
     * @param id 项目跟进记录主键
     * @return 项目跟进记录
     */
    public BusinessFollowRecord selectBusinessFollowRecordById(Long id);

    /**
     * 分页查询项目跟进记录列表
     * 
     * @param businessFollowRecord 项目跟进记录
     * @return 项目跟进记录集合
     */
    public List<BusinessFollowRecord> businessFollowRecordPaging(BusinessFollowRecord businessFollowRecord);

    /**
     * 根据项目id查询项目跟进记录
     *
     * @param businessId 项目id
     * @return 项目跟进记录集合
     */
    public List<BusinessFollowRecord> selectBusinessFollowRecordList(BusinessIdDto businessId);

    /**
     * 新增项目跟进记录
     * 
     * @param businessFollowRecord 项目跟进记录
     * @return 结果
     */
    public int insertBusinessFollowRecord(BusinessFollowRecord businessFollowRecord);

    /**
     * 修改项目跟进记录
     * 
     * @param businessFollowRecord 项目跟进记录
     * @return 结果
     */
    public int updateBusinessFollowRecord(BusinessFollowRecord businessFollowRecord);

    /**
     * 删除项目跟进记录
     * 
     * @param id 项目跟进记录主键
     * @return 结果
     */
    public int deleteBusinessFollowRecordById(Long id);

    /**
     * 批量删除项目跟进记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBusinessFollowRecordByIds(Long[] ids);
}
